from dash_bio.utils import *  # noqa: F401, F403, E402
import warnings

warnings.warn(
    """
The dash_bio_utils package is deprecated. Please replace
`import dash_bio_utils` with `from dash_bio.utils import *`""",
    stacklevel=2,
)
